@@ -4,9 +4,9 @@ OC.L10N.register(
     "Notes" : "הערות",
     "The last viewed note cannot be accessed. " : "אין גישה לפתק האחרון שנצפה.",
     "The notes folder is not accessible: %s" : "תיקיית הפתקים אינה נגישה: %s",
+    "New note" : "הערה חדשה",
     "Encryption Error" : "שגיאת הצפנה",
     "Error" : "שגיאה",
-    "New note" : "הערה חדשה",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
     "Settings" : "הגדרות",
@@ -19,12 +19,17 @@ OC.L10N.register(
     "Yesterday" : "אתמול",
     "This week" : "השבוע",
     "This month" : "החודש",
+    "Delete note" : "מחיקת הערה",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
-    "Delete note" : "מחיקת הערה",
+    "Details" : "פרטים",
+    "Preview" : "תצוגה מקדימה",
+    "Edit" : "עריכה",
     "Category" : "קטגוריה",
     "Uncategorized" : "ללא קטגוריה",
     "Saving failed!" : "השמירה נכשלה!",
-    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"]
+    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
+    "Android app" : "יישומון ל־Android",
+    "iOS app" : "יישומון ל־iOS"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
